// -----------------------------------------------------------------------------
//
// Author(s):     Peter Schraut (www.console-dev.de)
// Last Modified: 11th September 2006
//
// Purpose:       Demo shows how to use debug message macro. The LCD stays
//                black, this demo only outputs some debug messages into the
//                emulator debug message/logging window.
//
// Notes:
//                Debug messages are only available in HEL_DEBUG and HEL_CHECKED
//                mode. Please refer to the HEL 2 API documenation, section
//                "Library Overview" for more details about the different modes.
//
// -----------------------------------------------------------------------------
#include <hel2.h>



// -----------------------------------------------------------------------------
// Program Entry Point
// -----------------------------------------------------------------------------
int main(void)
{
    ham_Init();
    hel_SysSetPrefetch(TRUE);

	// Specify which message type you want to use.
	// HEL 2 Library supports debug message output
	// for the no$gba emulator and VisualBoy Advance.
	// To activate VisualBoy Advance messages, pass
	// DEBUG_MESSAGETYPE_VBA instead.
	hel_DebugSetMessageType(DEBUG_MESSAGETYPE_NOCASH);

	// Output a simple string
	HEL_DEBUG_MSG("Hello World\n");

	// Output a formatted string using the standard control-strings.
	// Display a float number
	HEL_DEBUG_MSG("PI is about %f\n", 3.1415926535f);

	// Display a result of an addition
	HEL_DEBUG_MSG("The result of 5+2 is %d\n", 5+2);

	// Display decimal and string
	HEL_DEBUG_MSG("Line number %d, file %s\n", __LINE__, __FILE__);

	// infinite loop
    for(;;)
    {
    }
    
    return 0;
}
