#include <hel2.h>

#define DrawText(x,y,txt,args...)    ham_DrawText(x,y,txt,##args)
//#define DrawText(x,y,txt,args...)


// column drawer routine for regular maps
// this function is triggered whenever a new column must be drawn
void MapDrawer_ColumnFunc(TMapInfo *pMapInfo, TMapDrawInfo *pDrawInfo)
{
  // pDrawInfo->pSourceCurrentDataAddr points to the first maptile in
  // the source mapdata array what the drawing system expects.
  // you dont need to calculate the source address, you can just use
  // this pointer! make sure to cast it to the correct type,
  // u16* in regular mode and u8* in rotation mode!
  u16 *TilePtr = (u16*)pDrawInfo->pSourceCurrentDataAddr;

  u32 Y;

  // pDrawInfo->TargetRow contains the index of the first row to update
  // and pDrawInfo->Quantity contains how many maptiles we want to draw.
  for(Y = pDrawInfo->TargetRow; Y<pDrawInfo->TargetRow+pDrawInfo->Quantity; Y++)
  {
    // set the maptile!
    ham_SetMapTile
      (
        pMapInfo->BgNo,           // background number
        pDrawInfo->TargetColumn,  // target column in vram
        Y & 31,                   // target row in vram
        *TilePtr                  // maptile
      );

    // move one row further
    TilePtr += pMapInfo->Size.X;
  }

  // draw some text
  DrawText(1, 1, "MapDrawer_ColumnFunc");
  DrawText(1, 2, "  X:%d, Y:%d     ", FIXED_TOINT(pMapInfo->Position.X), FIXED_TOINT(pMapInfo->Position.Y));
}

// row drawer routine for regular maps
// this function is triggered whenever a new row must be drawn
void MapDrawer_RowFunc(TMapInfo *pMapInfo, TMapDrawInfo *pDrawInfo)
{
  u16 *TilePtr = (u16*)pDrawInfo->pSourceCurrentDataAddr;
  u32 X;

  for(X = pDrawInfo->TargetColumn; X<pDrawInfo->TargetColumn+pDrawInfo->Quantity; X++)
  {
    ham_SetMapTile(pMapInfo->BgNo, X & 31, pDrawInfo->TargetRow, *TilePtr);
    TilePtr++;
  }

  // draw some text
  DrawText(1, 5, "MapDrawer_RowFunc");
  DrawText(1, 6, "  X:%d, Y:%d     ", FIXED_TOINT(pMapInfo->Position.X), FIXED_TOINT(pMapInfo->Position.Y));
}


