// -----------------------------------------------------------------------------
//
// Author(s):     Peter Schraut (www.console-dev.de)
// Last Modified: 18th April 2006
//
// Purpose:       Demo shows how to use the ExtractDigits function
//                and for what it can be used.
//
// -----------------------------------------------------------------------------
#include <hel2.h>
#include "ResourceData.h"

// -----------------------------------------------------------------------------
// Defines
// -----------------------------------------------------------------------------
#define DIGITS_COUNT 8

// -----------------------------------------------------------------------------
// Global Variables
// -----------------------------------------------------------------------------
u32 ATTR_EWRAM g_Score=0;
THandle ATTR_EWRAM g_Obj[DIGITS_COUNT];
u8 ATTR_EWRAM ATTR_ALIGNED(4) g_ObjSystemBuffer[HEL_SUBSYSTEM_OBJ_REQUIREDMEMORY];


// -----------------------------------------------------------------------------
// Prototypes
// -----------------------------------------------------------------------------
void InitObjects(void);
void UpdateObjects(void);
void VBLInterruptHandler(void);



// -----------------------------------------------------------------------------
// Program Entry Point
// -----------------------------------------------------------------------------
int main(void)
{
    ham_Init();
    hel_SysSetPrefetch(TRUE);
    ham_SetBgMode(0);
    
    // initialize Object-System
    hel_ObjInit(g_ObjSystemBuffer);
    
    // init objects
    InitObjects();
    
    // load object palette
    hel_PalObjLoad256(ResData16(RES_OBJECT_PAL));
    
    // Start VBL Interrupt
    hel_IntrStartHandler(INT_TYPE_VBL, (void*)VBLInterruptHandler);
    
    
    for(;;)
    {
        // increase score
        g_Score+=1;
        
        // update object graphics
        UpdateObjects();

        hel_SwiVBlankIntrWait();
    }
    
    return 0;
}

// -----------------------------------------------------------------------------
// Create DIGITS_COUNT objects
// -----------------------------------------------------------------------------
void InitObjects(void)
{
  int i;
  
  for(i=0; i<DIGITS_COUNT; i++)
  {
    g_Obj[i] = hel_ObjCreate256
                (
                  ResData(RES_DIGITS_RAW),// Sourcegraphic
                  OBJ_SHAPE_SQUARE,       // Object Shape
                  0,                      // Object Size
                  OBJ_MODE_NORMAL,        // Object Mode
                  10 + i*8,               // X
                  10                      // Y
                );
  }
}


// -----------------------------------------------------------------------------
// Update Objects, load new graphic into Vram.
// -----------------------------------------------------------------------------
void UpdateObjects(void)
{
  int i;
  u8 DigitsBuffer[DIGITS_COUNT];
  
  
  // Extract the digits from g_Score and store
  // them in DigitsBuffer!
  hel_MathExtractDigits
    (
      g_Score,            // Source Value
      (u8*)DigitsBuffer,  // Destination Buffer
      DIGITS_COUNT        // Count of digits to extract
    );
  
  
  // reload object graphic!
  for(i=0; i<DIGITS_COUNT; i++)
  {
    hel_ObjUpdateGfx
    (
      g_Obj[i],                                     // Obj Handle
      (void*)&ResData8(RES_DIGITS_RAW)[8*8*DigitsBuffer[i]]    // Pointer to new graphic, 8*8 = ObjSize and
                                                    // DigitsBuffer[i] contains the current number.
                                                    // Since the digits on the sourcegraphic are stacked,
                                                    // we can just use DigitsBuffer as multiplier to get
                                                    // the correct frame inside the sourcegraphic.
    );
  }
}

// -----------------------------------------------------------------------------
// VBL Interupt Handler
// -----------------------------------------------------------------------------
void VBLInterruptHandler(void)
{
  hel_ObjTransmit();

  hel_IntrAcknowledge(INT_TYPE_VBL);
}

