// -----------------------------------------------------------------------------
//
// Author(s):     Peter Schraut (www.console-dev.de)
// Last Modified: 18th April 2006
//
// Purpose:       Demo shows how to use Pad-System
//
//
// -----------------------------------------------------------------------------
#include <hel2.h>

// -----------------------------------------------------------------------------
// Variables
// -----------------------------------------------------------------------------
u32 ATTR_EWRAM g_nPressedB=0;

// -----------------------------------------------------------------------------
// Prototypes
// -----------------------------------------------------------------------------
void VBLInterruptHandler(void);


// -----------------------------------------------------------------------------
// Program Entry Point
// -----------------------------------------------------------------------------
int main(void)
{
    ham_Init();
    hel_SysSetPrefetch(TRUE);
    
    // Set background mode and init text
    ham_SetBgMode(0);
    ham_InitText(0);

    // Initialize the Pad-System
    hel_PadInit();
    
    // Start VBL Interrupt
    hel_IntrStartHandler(INT_TYPE_VBL, (void*)VBLInterruptHandler);
    
    // display instruction text
    ham_DrawText(1, 1,"Hold A or press B");
    

    for(;;)
    {
         // Call hel_PadCapture once per frame
         // to capture the current pad-state
         hel_PadCapture();

         // The hel_PadQuery function returns a pointer
         // to the pad information. It has a "Pressed"
         // and "Held" member.
         if(hel_PadQuery()->Held.A)
           ham_DrawText(1, 3,"A held");
         else
           ham_DrawText(1, 3,"       ");

         // Button -B- has been pressed this frame?
         if(hel_PadQuery()->Pressed.B)
           g_nPressedB++;

         // Display amount of -B- pressed
         ham_DrawText(1, 4,"B pressed %d times", g_nPressedB);
         
         // Wait for Vertical Blank
         hel_SwiVBlankIntrWait();
    }

    return 0;
}

// -----------------------------------------------------------------------------
// VBL Interupt Handler
// -----------------------------------------------------------------------------
void VBLInterruptHandler(void)
{
    // acknowledge interrupt
    hel_IntrAcknowledge(INT_TYPE_VBL);
}

