// -----------------------------------------------------------------------------
//
// Author(s):     Peter Schraut (www.console-dev.de)
// Last Modified: 18th April 2006
//
// Purpose:       Demo shows how to use the palette blend functions
//
// Notes:         Graphics borrowed from Nessie (http://nessie.gbadev.org)
//
// -----------------------------------------------------------------------------
#include <hel2.h>
#include "ResourceData.h"

// -----------------------------------------------------------------------------
// Global Variables
// -----------------------------------------------------------------------------
u8 ATTR_EWRAM ATTR_ALIGNED(4) g_MapSystemBuffer[HEL_SUBSYSTEM_MAP_REQUIREDMEMORY];

// -----------------------------------------------------------------------------
// Prototypes
// -----------------------------------------------------------------------------
void VBLInterruptHandler(void);



// -----------------------------------------------------------------------------
// Program Entry Point
// -----------------------------------------------------------------------------
int main(void)
{
    ham_Init();
    hel_SysSetPrefetch(TRUE);
    hel_PadInit();
    hel_MapInit(g_MapSystemBuffer);
    ham_SetBgMode(0);
    
    
    // Initialize 16 Color Tileset
    ham_bg[0].ti  = ham_InitTileSet(ResData(RES_WORLD1_LAYER2_RAW), RES_WORLD1_LAYER2_RAW_SIZE16, 0, TRUE);
    hel_MapCreate(0, 40, 22, ResData(RES_WORLD1_LAYER2_MAP), sizeof(u16), 0);

    // Turn on Background
    ham_InitBg(0, TRUE, 0, FALSE);
    
    // Start VBL Interrupt
    ham_StartIntHandler(INT_TYPE_VBL, (void*)VBLInterruptHandler);
    
    
    for(;;)
    {
        hel_PadCapture();

        static int BlendWeight=0;
        
        if(hel_PadQuery()->Held.Left)
          BlendWeight--;

        if(hel_PadQuery()->Held.Right)
          BlendWeight++;
          
        BlendWeight = LIMIT(BlendWeight, 0, 31);
        
        // Blend between background palettes
        hel_PalBgBlend16
          (
            ResData(RES_WORLD1_LAYER2_PAL),          // Palette A
            ResData(RES_WORLD1_LAYER2_EVENING_PAL),  // Palette B
            2,                                       // Palettebank
            BlendWeight                              // Blendweight (0..31)
          );
        
        // Wait for Vertical Blank
        hel_SwiVBlankIntrWait();
    }

    return 0;
}

// -----------------------------------------------------------------------------
// VBL Interrupt Handler
// -----------------------------------------------------------------------------
void VBLInterruptHandler()
{
    hel_IntrAcknowledge(INT_TYPE_VBL);
}

